# pyodide-water-background

Just for fun

Enter this code in the [https://pyodide.org/en/latest/console.html](console)

```py
import micropip, zengl; await micropip.install('waterbg'); import waterbg
```
